:mod:`nolearn.model`
--------------------

.. automodule:: nolearn.model

  .. autoclass:: AveragingEstimator
     :show-inheritance:

  .. autoclass:: FeatureStacker
     :show-inheritance:

  .. autoclass:: AbstractModel
